package com.ruoyi.bst.customer.service;

import java.time.LocalDateTime;
import java.util.List;

import com.ruoyi.bst.customer.domain.Customer;
import com.ruoyi.bst.customer.domain.CustomerQuery;
import com.ruoyi.bst.customer.domain.CustomerVO;
import com.ruoyi.bst.customer.domain.dto.CustomerAddDTO;
import com.ruoyi.common.vo.LocalDateIntegerVO;
import com.ruoyi.common.vo.StringIntegerVO;

/**
 * 客户Service接口
 *
 * @author ruoyi
 * @date 2025-01-22
 */
public interface CustomerService
{
    /**
     * 查询客户
     *
     * @param id 客户主键
     * @return 客户
     */
    public CustomerVO selectCustomerById(Long id);

    /**
     * 查询客户列表
     *
     * @param customer 客户
     * @return 客户集合
     */
    public List<CustomerVO> selectCustomerList(CustomerQuery customer);

    /**
     * 新增客户
     *
     * @param customer 客户
     * @return 结果
     */
    public int insertCustomer(CustomerAddDTO customer);

    /**
     * 修改客户
     *
     * @param customer 客户
     * @return 结果
     */
    public int updateCustomer(Customer customer);

    /**
     * 查询客户数量
     * @param query
     * @return
     */
    public int selectCount(CustomerQuery query);

    /**
     * 查询客户列表ByIds
     * @param ids
     * @return
     */
    List<CustomerVO> selectCustomerListByIds(List<Long> ids);

    /**
     * 查询客户数量
     * @param customerQuery
     * @return
     */
    List<StringIntegerVO> selectCountGroupByStatus(CustomerQuery customerQuery);

    /**
     * 更新客户跟进时间，
     * 新的最近跟进时间大于当前跟进时间
     * 新的下次跟进时间需要大于当前时间并且小于客户当前的下次跟进时间
     *
     * @param customerId     客户ID
     * @param lastFollowTime 新的跟进时间
     * @param nextFollowTime 新的下次跟进时间
     * @return
     */
    int updateFollowTime(Long customerId, LocalDateTime lastFollowTime, LocalDateTime nextFollowTime);

    /**
     * 逻辑删除
     * @param ids
     * @return
     */
    int logicDel(List<Long> ids);

    /**
     * 查询每日创建客户统计
     * @param query
     * @return
     */
    List<LocalDateIntegerVO> selectDailyCreateCount(CustomerQuery query);
}
