package com.ruoyi.bst.customerFollow.service.impl;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.support.TransactionTemplate;

import com.ruoyi.bst.customer.service.CustomerConverter;
import com.ruoyi.bst.customer.service.CustomerService;
import com.ruoyi.bst.customerFollow.domain.CustomerFollow;
import com.ruoyi.bst.customerFollow.domain.CustomerFollowQuery;
import com.ruoyi.bst.customerFollow.domain.CustomerFollowVO;
import com.ruoyi.bst.customerFollow.mapper.CustomerFollowMapper;
import com.ruoyi.bst.customerFollow.service.CustomerFollowService;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.common.utils.ServiceUtil;

/**
 * 客户跟进记录Service业务层处理
 *
 * @author ruoyi
 * @date 2025-01-22
 */
@Service
public class CustomerFollowServiceImpl implements CustomerFollowService
{
    @Autowired
    private CustomerFollowMapper customerFollowMapper;

    @Autowired
    private TransactionTemplate transactionTemplate;

    @Autowired
    private CustomerService customerService;

    @Autowired
    private CustomerConverter customerConverter;

    /**
     * 查询客户跟进记录
     *
     * @param followId 客户跟进记录主键
     * @return 客户跟进记录
     */
    @Override
    public CustomerFollowVO selectCustomerFollowByFollowId(Long followId)
    {
        return customerFollowMapper.selectCustomerFollowByFollowId(followId);
    }

    /**
     * 查询客户跟进记录列表
     *
     * @param customerFollow 客户跟进记录
     * @return 客户跟进记录
     */
    @Override
    public List<CustomerFollowVO> selectCustomerFollowList(CustomerFollowQuery customerFollow)
    {
        return customerFollowMapper.selectCustomerFollowList(customerFollow);
    }

    /**
     * 新增客户跟进记录
     *
     * @param customerFollow 客户跟进记录
     * @return 结果
     */
    @Override
    public int insertCustomerFollow(CustomerFollow data)
    {
        ServiceUtil.assertion(data.getCustomerId() == null, "客户ID不能为空");

        data.setUserId(SecurityUtils.getUserId());
        data.setCreateTime(DateUtils.getNowDate());

        Integer result = transactionTemplate.execute(status -> {
            // 新增客户跟进记录
            int insert = customerFollowMapper.insertCustomerFollow(data);

            if (insert > 0) {
                // 更新客户最近跟进时间
                customerService.updateFollowTime(data.getCustomerId(), data.getFollowTime(), data.getNextFollowTime());
            }

            return insert;
        });

        return result == null ? 0 : result;
    }

    /**
     * 修改客户跟进记录
     *
     * @param data 客户跟进记录
     * @return 结果
     */
    @Override
    public int updateCustomerFollow(CustomerFollow data) {
        Integer result = transactionTemplate.execute(status -> {
            int update = customerFollowMapper.updateCustomerFollow(data);

            if (update > 0) {
                // 更新客户最近跟进时间
                customerService.updateFollowTime(data.getCustomerId(), data.getFollowTime(), data.getNextFollowTime());
            }

            return update;
        });
        return result == null ? 0 : result;
    }

    /**
     * 批量删除客户跟进记录
     *
     * @param followIds 需要删除的客户跟进记录主键
     * @return 结果
     */
    @Override
    public int deleteCustomerFollowByFollowIds(Long[] followIds)
    {
        return customerFollowMapper.deleteCustomerFollowByFollowIds(followIds);
    }

    /**
     * 删除客户跟进记录信息
     *
     * @param followId 客户跟进记录主键
     * @return 结果
     */
    @Override
    public int deleteCustomerFollowByFollowId(Long followId)
    {
        return customerFollowMapper.deleteCustomerFollowByFollowId(followId);
    }
}
