package com.ruoyi.bst.notice.service.impl;

import java.util.Collections;
import java.util.List;
import java.util.stream.Collectors;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.ruoyi.bst.notice.domain.NoticeVO;
import com.ruoyi.bst.notice.service.NoticeAssembler;
import com.ruoyi.common.utils.collection.CollectionUtils;
import com.ruoyi.system.dept.domain.vo.SysDeptNameVO;
import com.ruoyi.system.dept.service.ISysDeptService;
import com.ruoyi.system.user.domain.vo.SysUserNameVO;
import com.ruoyi.system.user.service.UserService;

@Service
public class NoticeAssemblerImpl implements NoticeAssembler {

    @Autowired
    private UserService userService;

    @Autowired
    private ISysDeptService deptService;

    @Override
    public void assembleReceiveUserList(List<NoticeVO> list) {
        if (CollectionUtils.isEmptyElement(list)) {
            return;
        }

        List<SysUserNameVO> userList = userService.selectAllUserNameList();
        for (NoticeVO notice : list) {
            if (notice.getReceiveUserIds() == null) {
                notice.setReceiveUserList(Collections.emptyList());
                continue;
            }

            List<SysUserNameVO> receiveUserList = userList.stream()
                .filter(user -> notice.getReceiveUserIds().contains(user.getUserId()))
                .collect(Collectors.toList());
            notice.setReceiveUserList(receiveUserList);
        }
    }

    @Override
    public void assembleReceiveDeptList(List<NoticeVO> list) {
        if (CollectionUtils.isEmptyElement(list)) {
            return;
        }

        List<SysDeptNameVO> deptList = deptService.selectAllDeptNameList();
        for (NoticeVO notice : list) {
            if (notice.getReceiveDeptIds() == null) {
                notice.setReceiveDeptList(Collections.emptyList());
                continue;
            }

            List<SysDeptNameVO> receiveDeptList = deptList.stream()
                .filter(dept -> notice.getReceiveDeptIds().contains(dept.getDeptId()))
                .collect(Collectors.toList());
            notice.setReceiveDeptList(receiveDeptList);
        }
    }

}
