package com.ruoyi.bst.notice.service.impl;

import java.util.HashSet;
import java.util.List;
import java.util.Set;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.ruoyi.bst.message.domain.Message;
import com.ruoyi.bst.notice.domain.Notice;
import com.ruoyi.bst.notice.domain.NoticeQuery;
import com.ruoyi.bst.notice.domain.NoticeVO;
import com.ruoyi.bst.notice.mapper.NoticeMapper;
import com.ruoyi.bst.notice.service.NoticeService;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.system.user.service.UserService;
import com.ruoyi.ws.service.WebSocketService;

/**
 * 公告Service业务层处理
 *
 * @author ruoyi
 * @date 2025-02-10
 */
@Service
public class NoticeServiceImpl implements NoticeService
{
    @Autowired
    private NoticeMapper noticeMapper;

    @Autowired
    private WebSocketService webSocketService;

    @Autowired
    private UserService userService;


    /**
     * 查询公告
     *
     * @param id 公告主键
     * @return 公告
     */
    @Override
    public NoticeVO selectNoticeById(Long id)
    {
        return noticeMapper.selectNoticeById(id);
    }

    /**
     * 查询公告列表
     *
     * @param notice 公告
     * @return 公告
     */
    @Override
    public List<NoticeVO> selectNoticeList(NoticeQuery notice)
    {
        return noticeMapper.selectNoticeList(notice);
    }

    /**
     * 新增公告
     *
     * @param notice 公告
     * @return 结果
     */
    @Override
    public int insertNotice(Notice notice)
    {
        notice.setCreateTime(DateUtils.getNowDate());
        int rows = noticeMapper.insertNotice(notice);

        // 发送消息给接收人
        this.sendNotice(notice.getId());

        return rows;
    }

    /**
     * 修改公告
     *
     * @param notice 公告
     * @return 结果
     */
    @Override
    public int updateNotice(Notice notice)
    {
        int rows = noticeMapper.updateNotice(notice);

        // 发送消息给接收人
        this.sendNotice(notice.getId());

        return rows;
    }


    /**
     * 发送消息给接收人
     * @param id
     */
    private boolean sendNotice(Long id) {
        NoticeVO vo = this.selectNoticeById(id);
        if (vo == null) {
            return false;
        }

        // 获取接收人ID列表
        Set<Long> userIds = vo.getReceiveUserIds() == null ? new HashSet<>() : new HashSet<>(vo.getReceiveUserIds());
        userIds.addAll(userService.selectUserIdsByDeptIds(vo.getReceiveDeptIds()));

        // 发送消息给接收人
        Message message = new Message();
        message.setTitle("【公告】" + vo.getTitle());
        message.setContent(vo.getContent());
        webSocketService.sendMessageToUser(message, userIds);

        return true;
    }

    /**
     * 批量删除公告
     *
     * @param ids 需要删除的公告主键
     * @return 结果
     */
    @Override
    public int deleteNoticeByIds(Long[] ids)
    {
        return noticeMapper.deleteNoticeByIds(ids);
    }

    /**
     * 删除公告信息
     *
     * @param id 公告主键
     * @return 结果
     */
    @Override
    public int deleteNoticeById(Long id)
    {
        return noticeMapper.deleteNoticeById(id);
    }
}
