package com.ruoyi.bst.project.domain;

import java.math.BigDecimal;
import java.time.LocalDate;
import java.time.LocalDateTime;
import java.util.List;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.Size;

import org.springframework.format.annotation.DateTimeFormat;

import com.ruoyi.common.annotation.Excel;
import com.ruoyi.common.core.domain.BaseEntity;
import com.ruoyi.common.core.validate.ValidGroup;
import com.ruoyi.common.vo.FileNameVO;

import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

/**
 * 项目对象 bst_project
 *
 * @author ruoyi
 * @date 2025-01-22
 */
@Data
public class Project extends BaseEntity
{
    private static final long serialVersionUID = 1L;

    private Long id;

    @Excel(name = "项目编号")
    @ApiModelProperty("项目编号")
    private String no;

    @Excel(name = "项目名称")
    @ApiModelProperty("项目名称")
    @NotBlank(message = "项目名称不能为空", groups = {ValidGroup.Create.class})
    @Size(max = 50, message = "项目名称长度不能超过50个字符")
    private String name;

    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @Excel(name = "到期时间", width = 30, dateFormat = "yyyy-MM-dd HH:mm:ss")
    @ApiModelProperty("到期时间")
    private LocalDate expireTime;

    @Excel(name = "负责人ID")
    @ApiModelProperty("负责人ID")
    private Long ownerId;

    @Excel(name = "跟进人ID")
    @ApiModelProperty("跟进人ID")
    private Long followId;

    @Excel(name = "项目金额")
    @ApiModelProperty("项目金额")
    private BigDecimal amount;

    @Excel(name = "已收金额")
    @ApiModelProperty("已收金额")
    private BigDecimal receivedAmount;

    @Excel(name = "运维费用")
    @ApiModelProperty("运维费用")
    private String operationAmount;

    @Excel(name = "状态", readConverterExp = "1=进行中,2=已完成,3=维护,4=开发超期,5=维护超期")
    @ApiModelProperty("状态")
    private String status;

    @Excel(name = "附件")
    @ApiModelProperty("附件")
    private List<FileNameVO> attaches;

    @Excel(name = "客户ID")
    @ApiModelProperty("客户ID")
    private Long customerId;

    @Excel(name = "创建人ID")
    @ApiModelProperty("创建人ID")
    private Long createId;

    @Excel(name = "完成时间", width = 30, dateFormat = "yyyy-MM-dd HH:mm:ss")
    @ApiModelProperty("完成时间")
    private LocalDateTime completeTime;

    @Excel(name = "预计完成日期", width = 30, dateFormat = "yyyy-MM-dd")
    @ApiModelProperty("预计完成日期")
    private LocalDate expectedCompleteDate;

    @Excel(name = "开始时间", width = 30, dateFormat = "yyyy-MM-dd HH:mm:ss")
    @ApiModelProperty("开始时间")
    private LocalDateTime startTime;

    @Excel(name = "验收时间", width = 30, dateFormat = "yyyy-MM-dd HH:mm:ss")
    @ApiModelProperty("验收时间")
    private LocalDateTime acceptTime;

    @Excel(name = "维护到期日期", width = 30, dateFormat = "yyyy-MM-dd")
    @ApiModelProperty("维护到期日期")
    private LocalDate maintenanceEndDate;

    @Excel(name = "开发是否超期")
    @ApiModelProperty("开发是否超期")
    private Boolean devOverdue;

    @Excel(name = "项目成员列表")
    @ApiModelProperty("项目成员列表")
    private List<Long> memberIds;
}
