package com.ruoyi.bst.project.domain.enums;

import java.util.Arrays;
import java.util.List;

import com.ruoyi.common.utils.collection.CollectionUtils;

import lombok.AllArgsConstructor;
import lombok.Getter;

@Getter
@AllArgsConstructor
public enum ProjectStatus {

    WAIT_START("WAIT_START", "待开始"),
    IN_PROGRESS("IN_PROGRESS", "进行中"),
    COMPLETED("COMPLETED", "完成开发"),
    ACCEPTED("ACCEPTED", "已验收"),
    MAINTENANCE("MAINTENANCE", "维护中"),
    MAINTENANCE_OVERDUE("MAINTENANCE_OVERDUE", "维护到期"),
    DEVELOPMENT_OVERDUE("DEVELOPMENT_OVERDUE", "开发超期");

    private final String status;
    private final String name;

    /**
     * 可以完成的项目状态
     * @return
     */
    public static List<String> canComplete() {
        return Arrays.asList(IN_PROGRESS.getStatus(), DEVELOPMENT_OVERDUE.getStatus());
    }

    /**
     * 可以开始的项目状态
     * @return
     */
    public static List<String> canStart() {
        return Arrays.asList(WAIT_START.getStatus());
    }

    /**
     * 可以验收的项目状态
     * @return
     */
    public static List<String> canAccept() {
        return Arrays.asList(COMPLETED.getStatus());
    }

    /**
     * 可以维护的项目状态
     * @return
     */
    public static List<String> canMaintenance() {
        return Arrays.asList(ACCEPTED.getStatus(), MAINTENANCE_OVERDUE.getStatus());
    }

    /**
     * 开发完成的项目状态
     * @return
     */
    public static List<String> completedList() {
        return CollectionUtils.map(ProjectStatus::getStatus, 
            COMPLETED,
            ACCEPTED,
            MAINTENANCE,
            MAINTENANCE_OVERDUE
        );
    }

    /**
     * 未完成开发的项目状态
     */
    public static List<String> devNotFinish() {
        return CollectionUtils.map(ProjectStatus::getStatus, 
            WAIT_START,
            IN_PROGRESS
        );
    }

    /**
     * 可以维护超期的项目状态
     * @return
     */
    public static List<String> canMaintenanceOverdue() {
        return CollectionUtils.map(ProjectStatus::getStatus, 
            MAINTENANCE
        );
    }

}
