package com.ruoyi.bst.project.service;

import java.util.List;

import com.ruoyi.bst.project.domain.Project;
import com.ruoyi.bst.project.domain.ProjectQuery;
import com.ruoyi.bst.project.domain.ProjectVO;
import com.ruoyi.bst.project.domain.dto.ProjectMaintenanceDTO;
import com.ruoyi.bst.project.domain.dto.ProjectStartDTO;
import com.ruoyi.bst.project.domain.vo.ProjectNameVO;
import com.ruoyi.common.vo.IntegerIntegerVO;
import com.ruoyi.common.vo.StringIntegerVO;

/**
 * 项目Service接口
 *
 * @author ruoyi
 * @date 2025-01-22
 */
public interface ProjectService
{
    /**
     * 查询项目
     *
     * @param id 项目主键
     * @return 项目
     */
    public ProjectVO selectProjectById(Long id);

    /**
     * 查询项目列表
     *
     * @param project 项目
     * @return 项目集合
     */
    public List<ProjectVO> selectProjectList(ProjectQuery project);

    /**
     * 新增项目
     *
     * @param project 项目
     * @return 结果
     */
    public int insertProject(Project project);

    /**
     * 修改项目
     *
     * @param project 项目
     * @return 结果
     */
    public int updateProject(Project project);

    /**
     * 批量删除项目
     *
     * @param ids 需要删除的项目主键集合
     * @return 结果
     */
    public int logicDel(List<Long> ids);

    /**
     * 查询所有项目名称
     *
     * @return 项目名称集合
     */
    public List<ProjectNameVO> selectAllNameList();

    /**
     * 查询项目数量
     * @param query
     * @return
     */
    int selectCount(ProjectQuery query);

    /**
     * 查询项目数量
     * @param query
     * @return
     */
    List<StringIntegerVO> selectCountGroupByStatus(ProjectQuery query);

    /**
     * 项目完成
     * @param id
     * @return
     */
    int complete(Long id);

    /**
     * 项目开始
     * @param dto
     * @return
     */
    int start(ProjectStartDTO dto);

    /**
     * 项目验收
     * @param id
     * @return
     */
    int accept(Long id);

    /**
     * 维护
     * @param dto
     * @return
     */
    int maintenance(ProjectMaintenanceDTO dto);

    /**
     * 按创建月份分组查询数量
     * @param query
     */
    List<IntegerIntegerVO> selectCountGroupByCreateMonth(ProjectQuery query);

    /**
     * 按完成月份分组查询数量
     * @param query
     * @return
     */
    List<IntegerIntegerVO> selectCountGroupByCompleteMonth(ProjectQuery query);

    /**
     * 按开始月份分组查询数量
     * @param query
     * @return
     */
    List<IntegerIntegerVO> selectCountGroupByStartMonth(ProjectQuery query);

    /**
     * 处理超出开发时间还未完成开发的项目，并打上超期标识
     */
    int handleDevOverdueProject(ProjectQuery query);

    /**
     * 处理维护超期的项目，并打上超期标识
     */
    int handleMaintenanceOverdueProject(ProjectQuery query);

}
