package com.ruoyi.bst.project.service.impl;

import java.util.Collections;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.ruoyi.bst.project.domain.ProjectVO;
import com.ruoyi.bst.project.service.ProjectAssembler;
import com.ruoyi.bst.task.domain.TaskQuery;
import com.ruoyi.bst.task.domain.enums.TaskStatus;
import com.ruoyi.bst.task.service.TaskService;
import com.ruoyi.common.utils.collection.CollectionUtils;
import com.ruoyi.common.vo.LongIntegerVO;
import com.ruoyi.system.user.domain.vo.SysUserNameVO;
import com.ruoyi.system.user.service.UserService;

@Service
public class ProjectAssemblerImpl implements ProjectAssembler {

    @Autowired
    private TaskService taskService;

    @Autowired
    private UserService userService;

    @Override
    public void assembleTaskCount(List<ProjectVO> list) {
        if (CollectionUtils.isEmptyElement(list)) {
            return;
        }

        Map<Long, Integer> taskCountMap = this.selectTaskCountByProjects(list, null);

        for (ProjectVO project : list) {
            Integer count = taskCountMap.get(project.getId());
            if (count == null) {
                count = 0;
            }
            project.setTaskCount(count);
        }
    }

    @Override
    public void assembleTaskPassCount(List<ProjectVO> list) {
        if (CollectionUtils.isEmptyElement(list)) {
            return;
        }
        Map<Long, Integer> taskCountMap = this.selectTaskCountByProjects(list, TaskStatus.PASS.getStatus());

        for (ProjectVO project : list) {
            Integer count = taskCountMap.get(project.getId());
            if (count == null) {
                count = 0;
            }
            project.setTaskPassCount(count);
        }
    }

    @Override
    public void assembleTaskWaitConfirmCount(List<ProjectVO> list) {
        if (CollectionUtils.isEmptyElement(list)) {
            return;
        }
        Map<Long, Integer> taskCountMap = this.selectTaskCountByProjects(list, TaskStatus.WAIT_CONFIRM.getStatus());

        for (ProjectVO project : list) {
            Integer count = taskCountMap.get(project.getId());
            if (count == null) {
                count = 0;
            }
            project.setTaskWaitConfirmCount(count);
        }
    }

    /**
     * 根据项目id查询任务数量
     */
    private Map<Long, Integer> selectTaskCountByProjects(List<ProjectVO> list, String status) {
        TaskQuery query = new TaskQuery();
        query.setScope(true);
        query.setStatus(status);
        query.setProjectIds(CollectionUtils.map(list, ProjectVO::getId));
        return taskService.selectCountGroupByProject(query)
            .stream()
            .filter(vo -> vo.getKey() != null)
            .collect(Collectors.toMap(LongIntegerVO::getKey, LongIntegerVO::getValue));
    }

    @Override
    public void assembleMemberList(List<ProjectVO> list) {
        if (CollectionUtils.isEmptyElement(list)) {
            return;
        }

        List<SysUserNameVO> memberList = userService.selectAllUserNameList();

        for (ProjectVO project : list) {
            if (project.getMemberIds() == null) {
                project.setMemberList(Collections.emptyList());
                continue;
            }
            List<SysUserNameVO> projectMemberList = memberList.stream()
                .filter(item -> project.getMemberIds().contains(item.getUserId()))
                .collect(Collectors.toList());
            project.setMemberList(projectMemberList);
        }
    }

}
