package com.ruoyi.bst.task.domain;

import java.time.LocalDateTime;
import java.util.List;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.Size;

import org.springframework.format.annotation.DateTimeFormat;

import com.ruoyi.common.annotation.Excel;
import com.ruoyi.common.constant.DictType;
import com.ruoyi.common.core.domain.BaseEntity;
import com.ruoyi.common.core.validate.ValidGroup;
import com.ruoyi.system.valid.DictValid;

import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

/**
 * 任务对象 bst_task
 *
 * @author ruoyi
 * @date 2025-01-22
 */
@Data
public class Task extends BaseEntity
{
    private static final long serialVersionUID = 1L;

    private Long id;

    @Excel(name = "项目ID")
    @ApiModelProperty("项目ID")
    private Long projectId;

    @Excel(name = "类型", readConverterExp = "1=功能,2=优化,3=BUG")
    @ApiModelProperty("类型")
    @NotBlank(message = "类型不能为空", groups = {ValidGroup.Create.class})
    @DictValid(type = DictType.TASK_TYPE, message = "非法的类型值")
    private String type;

    @Excel(name = "状态", readConverterExp = "1=待完成,2=进行中,3=待确认,4=通过,5=驳回")
    @ApiModelProperty("状态")
    private String status;

    @Excel(name = "优先级", readConverterExp = "1=高,2=中,3=低")
    @ApiModelProperty("优先级")
    @NotBlank(message = "优先级不能为空", groups = {ValidGroup.Create.class})
    @DictValid(type = DictType.TASK_LEVEL, message = "非法的优先级值")
    private String level;

    @Excel(name = "图片")
    @ApiModelProperty("图片")
    private String picture;

    @Excel(name = "创建人ID")
    @ApiModelProperty("创建人ID")
    private Long createId;

    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @Excel(name = "截止时间", width = 30, dateFormat = "yyyy-MM-dd HH:mm:ss")
    @ApiModelProperty("截止时间")
    private LocalDateTime expireTime;

    @Excel(name = "负责人ID")
    @ApiModelProperty("负责人ID")
    @Size(min = 1, message = "负责人不能为空", groups = {ValidGroup.Create.class})
    private List<Long> ownerIds;

    @Excel(name = "任务内容")
    @ApiModelProperty("任务内容")
    @Size(max = 1000, message = "任务内容长度不能超过1000个字符")
    private String description;

    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @Excel(name = "预计完成时间", width = 30, dateFormat = "yyyy-MM-dd HH:mm:ss")
    @ApiModelProperty("预计完成时间")
    private LocalDateTime expectFinishTime;

    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @Excel(name = "通过时间", width = 30, dateFormat = "yyyy-MM-dd HH:mm:ss")
    @ApiModelProperty("通过时间")
    private LocalDateTime passTime;

    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @Excel(name = "取消时间", width = 30, dateFormat = "yyyy-MM-dd HH:mm:ss")
    @ApiModelProperty("取消时间")
    private LocalDateTime cancelTime;

    @Excel(name = "取消操作人ID")
    @ApiModelProperty("取消操作人ID")
    private Long cancelUserId;

    @Excel(name = "取消备注")
    @ApiModelProperty("取消备注")
    private String cancelRemark;
}
