package com.ruoyi.bst.task.service;

import java.util.List;

import com.ruoyi.bst.task.domain.Task;
import com.ruoyi.bst.task.domain.TaskQuery;
import com.ruoyi.bst.task.domain.TaskVO;
import com.ruoyi.bst.task.domain.dto.TaskCancelDTO;
import com.ruoyi.bst.task.domain.dto.TaskSubmitDTO;
import com.ruoyi.common.vo.LongIntegerVO;
import com.ruoyi.common.vo.StringIntegerVO;

/**
 * 任务Service接口
 *
 * @author ruoyi
 * @date 2025-01-22
 */
public interface TaskService
{
    /**
     * 查询任务
     *
     * @param id 任务主键
     * @return 任务
     */
    public TaskVO selectTaskById(Long id);

    /**
     * 查询任务列表
     *
     * @param task 任务
     * @return 任务集合
     */
    public List<TaskVO> selectTaskList(TaskQuery task);

    /**
     * 新增任务
     *
     * @param task 任务
     * @return 结果
     */
    public int insertTask(Task task);

    /**
     * 修改任务
     *
     * @param task 任务
     * @return 结果
     */
    public int updateTask(Task task);

    /**
     * 批量删除任务
     *
     * @param ids 需要删除的任务主键集合
     * @return 结果
     */
    public int logicDel(List<Long> ids);

    /**
     * 查询任务数量
     * @param query
     * @return
     */
    List<StringIntegerVO> selectCountGroupByStatus(TaskQuery query);

    /**
     * 查询任务数量
     * @param query
     * @return
     */
    public int selectCount(TaskQuery query);

    /**
     * 查询任务数量
     * @param query
     * @return
     */
    List<LongIntegerVO> selectCountGroupByProject(TaskQuery query);

    /**
     * 提交任务
     * @param dto
     * @return
     */
    int submitTask(TaskSubmitDTO dto);

    /**
     * 取消任务
     * @param dto
     * @return
     */
    int cancelTask(TaskCancelDTO dto);

    /**
     * 根据条件更新任务
     * @param task
     * @param taskQuery
     * @return
     */
    int updateByQuery(Task task, TaskQuery taskQuery);

    /**
     * 通过任务（结束）
     * @param id
     * @return
     */
    int passTask(Long id);

    /**
     * 更新任务状态为进行中
     * @param taskId
     */
    int startTask(Long taskId);

    /**
     * 查询任务类型数量
     * @param query
     * @return
     */
    List<StringIntegerVO> selectCountGroupByType(TaskQuery query);


}
