package com.ruoyi.bst.task.service.impl;

import java.util.Collections;
import java.util.List;
import java.util.Map;
import java.util.Objects;
import java.util.stream.Collectors;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.ruoyi.bst.task.domain.TaskVO;
import com.ruoyi.bst.task.service.TaskAssembler;
import com.ruoyi.bst.taskSubmit.domain.TaskSubmitQuery;
import com.ruoyi.bst.taskSubmit.domain.TaskSubmitVO;
import com.ruoyi.bst.taskSubmit.domain.enums.TaskSubmitStatus;
import com.ruoyi.bst.taskSubmit.service.TaskSubmitService;
import com.ruoyi.common.utils.collection.CollectionUtils;
import com.ruoyi.common.vo.LongIntegerVO;
import com.ruoyi.system.user.domain.vo.SysUserNameVO;
import com.ruoyi.system.user.service.UserService;

@Service
public class TaskAssemblerImpl implements TaskAssembler {


    @Autowired
    private TaskSubmitService taskSubmitService;

    @Autowired
    private UserService userService;

    @Override
    public void assembleSubmitList(List<TaskVO> list) {
        if (CollectionUtils.isEmptyElement(list)) {
            return;
        }
        
        // 查询列表
        List<Long> taskIds = CollectionUtils.map(list, TaskVO::getId);
        List<TaskSubmitVO> submitList = taskSubmitService.selectListByTaskIds(taskIds);

        // 组装列表
        for (TaskVO task : list) {
            List<TaskSubmitVO> taskSubmitList = submitList.stream()
                .filter(item -> Objects.equals(item.getTaskId(), task.getId()))
                .collect(Collectors.toList());
            task.setSubmitList(taskSubmitList);
        }
    }
    
    @Override
    public void assembleOwnerList(List<TaskVO> list) {
        if (CollectionUtils.isEmptyElement(list)) {
            return;
        }
        List<SysUserNameVO> userList = userService.selectAllUserNameList();
        
        for (TaskVO task : list) {
            if (task.getOwnerIds() == null || task.getOwnerIds().isEmpty()) {
                task.setOwnerList(Collections.emptyList());
                continue;
            }
            List<SysUserNameVO> ownerList = userList.stream()
                .filter(item -> task.getOwnerIds().contains(item.getUserId()))
                .collect(Collectors.toList());
            task.setOwnerList(ownerList);
        }
    }

    @Override
    public void assembleSubmitCount(List<TaskVO> list) {
        if (CollectionUtils.isEmptyElement(list)) {
            return;
        }
        
        List<Long> taskIds = CollectionUtils.map(list, TaskVO::getId);
        TaskSubmitQuery query = new TaskSubmitQuery();
        query.setTaskIds(taskIds);
        Map<Long, Integer> map = taskSubmitService.selectCountGroupByTaskId(query)
            .stream().collect(Collectors.toMap(LongIntegerVO::getKey, LongIntegerVO::getValue));

        for (TaskVO vo : list) {
            Integer count = map.get(vo.getId());
            if (count == null) {
                count = 0;
            }
            vo.setSubmitCount(count);
        }
    }
    

    @Override
    public void assemblePassCount(List<TaskVO> list) {
        if (CollectionUtils.isEmptyElement(list)) {
            return;
        }
        
        List<Long> taskIds = CollectionUtils.map(list, TaskVO::getId);
        TaskSubmitQuery query = new TaskSubmitQuery();
        query.setTaskIds(taskIds);
        query.setStatus(TaskSubmitStatus.PASS.getCode());
        Map<Long, Integer> map = taskSubmitService.selectCountGroupByTaskId(query)
            .stream().collect(Collectors.toMap(LongIntegerVO::getKey, LongIntegerVO::getValue));

        for (TaskVO vo : list) {
            Integer count = map.get(vo.getId());
            if (count == null) {
                count = 0;
            }
            vo.setPassCount(count);
        }
    }
}
