package com.ruoyi.bst.task.service.impl;

import java.util.Objects;

import org.apache.commons.collections4.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.ruoyi.bst.task.domain.Task;
import com.ruoyi.bst.task.domain.TaskVO;
import com.ruoyi.bst.task.service.TaskService;
import com.ruoyi.bst.task.service.TaskValidator;
import com.ruoyi.common.utils.ServiceUtil;

@Service
public class TaskValidatorImpl implements TaskValidator{

    @Autowired
    private TaskService taskService;

    @Override
    public boolean allowSubmit(Long id, Long userId) {
        if (id == null || userId == null) {
            return false;
        }
        TaskVO task = taskService.selectTaskById(id);
        return this.isOwner(task, userId);
    }

    @Override
    public boolean allowStart(Long id, Long userId) {
        if (id == null || userId == null) {
            return false;
        }
        TaskVO task = taskService.selectTaskById(id);
        return this.isOwner(task, userId);
    }

    // 校验当前用户是否是任务的负责人
    private boolean isOwner(Task task, Long userId) {
        return task != null && task.getOwnerIds() != null && task.getOwnerIds().contains(userId);
    }

    @Override
    public void validate(TaskVO vo) {
        ServiceUtil.assertion(vo == null, "任务不能为空");

        if (vo.getProjectId() != null && CollectionUtils.isNotEmpty(vo.getOwnerIds())) {
            // 判断负责人是否是项目的成员
            for (Long ownerId : vo.getOwnerIds()) {
                boolean isMember = Objects.equals(vo.getProjectOwnerId(), ownerId)
                        || Objects.equals(vo.getProjectFollowId(), ownerId)
                        || vo.getProjectMemberIds().contains(ownerId);
                if (!isMember) {
                    throw new RuntimeException(String.format("ID为%s的负责人不是项目的成员", ownerId));
                }
            }
        }

    }
}
