package com.ruoyi.dashboard.index.domain.brief;
import java.util.List;

import com.ruoyi.bst.task.domain.enums.TaskStatus;
import com.ruoyi.bst.task.domain.enums.TaskType;
import com.ruoyi.common.vo.StringIntegerVO;

import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

@Data
public class TaskBriefVO {

    @ApiModelProperty("任务总数")
    private Integer total;
        
    // 状态分组
    @ApiModelProperty("待完成")
    private Integer waitCompleted;
    @ApiModelProperty("进行中")
    private Integer inProgress;
    @ApiModelProperty("待确认")
    private Integer waitConfirm;
    @ApiModelProperty("已完成")
    private Integer completed;
    @ApiModelProperty("驳回")
    private Integer reject;

    // 类型分组
    @ApiModelProperty("BUG数")
    private Integer bug;
    @ApiModelProperty("新功能")
    private Integer newFunction;
    @ApiModelProperty("优化")
    private Integer optimization;

    @ApiModelProperty("逾期未完成")
    private Integer overdueUncompleted;

    @ApiModelProperty("逾期完成")
    private Integer overdueCompleted;

    // 设置状态分组数据
    public void setStatusGroup(List<StringIntegerVO> statusMap) {
        this.waitCompleted = statusMap.stream()
                .filter(vo -> TaskStatus.WAIT_COMPLETED.getStatus().equals(vo.getKey()))
                .findFirst().map(StringIntegerVO::getValue).orElse(0);

        this.inProgress = statusMap.stream()
                .filter(vo -> TaskStatus.PROCESSING.getStatus().equals(vo.getKey()))
                .findFirst().map(StringIntegerVO::getValue).orElse(0);

        this.waitConfirm = statusMap.stream()
                .filter(vo -> TaskStatus.WAIT_CONFIRM.getStatus().equals(vo.getKey()))
                .findFirst().map(StringIntegerVO::getValue).orElse(0);

        this.completed = statusMap.stream()
                .filter(vo -> TaskStatus.PASS.getStatus().equals(vo.getKey()))
                .findFirst().map(StringIntegerVO::getValue).orElse(0);

        this.reject = statusMap.stream()
                .filter(vo -> TaskStatus.REJECT.getStatus().equals(vo.getKey()))
                .findFirst().map(StringIntegerVO::getValue).orElse(0);

        this.total = statusMap.stream().map(StringIntegerVO::getValue).reduce(0, Integer::sum);
    }

    // 设置类型分组数据
    public void setTypeGroup(List<StringIntegerVO> typeMap) {
        this.bug = typeMap.stream()
                .filter(vo -> TaskType.BUG.getType().equals(vo.getKey()))
                .findFirst().map(StringIntegerVO::getValue).orElse(0);

        this.newFunction = typeMap.stream()
                .filter(vo -> TaskType.FUNCTION.getType().equals(vo.getKey()))
                .findFirst().map(StringIntegerVO::getValue).orElse(0);

        this.optimization = typeMap.stream()
                .filter(vo -> TaskType.OPTIMIZATION.getType().equals(vo.getKey()))
                .findFirst().map(StringIntegerVO::getValue).orElse(0);

        this.total = typeMap.stream().map(StringIntegerVO::getValue).reduce(0, Integer::sum);
    }

}
