package com.ruoyi.dashboard.project.service;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.Objects;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.ruoyi.bst.project.domain.ProjectQuery;
import com.ruoyi.bst.project.domain.enums.ProjectStatus;
import com.ruoyi.bst.project.service.ProjectService;
import com.ruoyi.common.utils.bean.BeanUtils;
import com.ruoyi.common.vo.IntegerIntegerVO;
import com.ruoyi.common.vo.StringIntegerVO;
import com.ruoyi.dashboard.index.domain.brief.ProjectBriefVO;
import com.ruoyi.dashboard.project.domain.brief.ProjectBriefKeys;
import com.ruoyi.dashboard.project.domain.monthProject.MonthProjectQuery;
import com.ruoyi.dashboard.project.domain.monthProject.MonthProjectVO;
import com.ruoyi.dashboard.project.domain.projectRate.ProjectRateVO;

@Service
public class DashboardProjectService {

    @Autowired
    private ProjectService projectService;

    public List<MonthProjectVO> selectMonthProject(MonthProjectQuery query) {
        List<MonthProjectVO> result = new ArrayList<>();

        // 查询每月新增的项目数
        List<IntegerIntegerVO> startList = this.selectCoungGroupByStartMonth(query);

        // 查询每月完成的项目数
        List<IntegerIntegerVO> finishList = this.selectCountGroupByCompleteMonth(query);

        // 构造成12月的数据
        for (int i = 1; i <= 12; i ++) {
            MonthProjectVO vo = new MonthProjectVO();
            vo.setYear(query.getYear());
            vo.setMonth(i);

            // 开始项目
            IntegerIntegerVO startCount = startList.stream().filter(item -> Objects.equals(vo.getMonth(), item.getKey())).findFirst().orElse(null);
            if (startCount == null || startCount.getValue() == null) {
                vo.setStartCount(0);
            } else {
                vo.setStartCount(startCount.getValue());
            }

            // 完成项目
            IntegerIntegerVO finishCount = finishList.stream().filter(item -> Objects.equals(vo.getMonth(), item.getKey())).findFirst().orElse(null);
            if (finishCount == null || finishCount.getValue() == null) {
                vo.setFinishCount(0);
            } else {
                vo.setFinishCount(finishCount.getValue());
            }

            result.add(vo);
        }

        return result;
    }

    // 查询项目概览
    public ProjectBriefVO selectProjectBrief(ProjectQuery query, String ...keys) {

        ProjectBriefVO vo = new ProjectBriefVO();

        if (keys != null) {
            List<String> keyList = Arrays.asList(keys);

            if (keyList.contains(ProjectBriefKeys.STATUS)) {
                List<StringIntegerVO> projectMap = projectService.selectCountGroupByStatus(query);
                vo.setStatusGroup(projectMap);
            }
            if (keyList.contains(ProjectBriefKeys.DEV_COMPLETED)) {
                int devCompleted = this.selectDevCompletedCount(query);
                vo.setDevCompleted(devCompleted);
            }
            if (keyList.contains(ProjectBriefKeys.OVERDUE_DEV_UNCOMPLETED)) {
                int devOverdueUncompleted = this.selectDevOverdueUncompletedCount(query);
                vo.setDevOverdueUncompleted(devOverdueUncompleted);
            }
            if (keyList.contains(ProjectBriefKeys.OVERDUE_DEV_COMPLETED)) {
                int devOverdueCompleted = this.selectDevOverdueCompletedCount(query);
                vo.setDevOverdueCompleted(devOverdueCompleted);
            }
        }

        return vo;
    }

    // 按月查询新增项目数
    public List<IntegerIntegerVO> selectCountGroupByCreateMonth(MonthProjectQuery query) {
        ProjectQuery projectQuery = new ProjectQuery();
        projectQuery.setCreateYear(query.getYear());
        return projectService.selectCountGroupByCreateMonth(projectQuery);
    }

    // 按月查询完成项目数
    public List<IntegerIntegerVO> selectCountGroupByCompleteMonth(MonthProjectQuery query) {
        ProjectQuery projectQuery = new ProjectQuery();
        projectQuery.setCompleteYear(query.getYear());
        return projectService.selectCountGroupByCompleteMonth(projectQuery);
    }

    // 按月查询开始项目数
    public List<IntegerIntegerVO> selectCoungGroupByStartMonth(MonthProjectQuery query) {
        ProjectQuery projectQuery = new ProjectQuery();
        projectQuery.setStartYear(query.getYear());
        return projectService.selectCountGroupByStartMonth(projectQuery);
    }

    // 获取项目比率
    public ProjectRateVO selectProjectRate() {
        ProjectRateVO result = new ProjectRateVO();

        // 查询总数
        ProjectQuery query = new ProjectQuery();
        query.setScope(true);
        int total = projectService.selectCount(query);
        result.setTotal(total);

        // 查询完成数
        result.setCompleted(this.selectCompletedCount());

        // 查询超期数
        result.setDevOverdue(this.selectDevOverdueCount());

        return result;
    }

    // 查询完成数
    private int selectCompletedCount() {
        ProjectQuery query = new ProjectQuery();
        query.setStatusList(ProjectStatus.completedList());
        query.setScope(true);
        return projectService.selectCount(query);
    }

    // 查询开发超期数
    private int selectDevOverdueCount() {
        ProjectQuery query = new ProjectQuery();
        query.setDevOverdue(true);
        query.setScope(true);
        return projectService.selectCount(query);
    }

    // 查询正常开发完成数
    private int selectDevCompletedCount(ProjectQuery projectQuery) {
        ProjectQuery query = new ProjectQuery();
        BeanUtils.copyBeanProp(query, projectQuery);
        query.setStatusList(ProjectStatus.completedList());
        query.setDevOverdue(false);
        return projectService.selectCount(query);
    }

    // 开发逾期未完成
    private int selectDevOverdueUncompletedCount(ProjectQuery projectQuery) {
        ProjectQuery query = new ProjectQuery();
        BeanUtils.copyBeanProp(query, projectQuery);
        query.setDevOverdue(true);
        query.setStatusList(ProjectStatus.devNotFinish());
        return projectService.selectCount(query);
    }

    // 开发逾期完成
    private int selectDevOverdueCompletedCount(ProjectQuery projectQuery) {
        ProjectQuery query = new ProjectQuery();
        BeanUtils.copyBeanProp(query, projectQuery);
        query.setDevOverdue(true);
        query.setStatusList(ProjectStatus.completedList());
        return projectService.selectCount(query);
    }

}
