package com.ruoyi.dashboard.task.service;

import java.util.Arrays;
import java.util.List;

import com.ruoyi.common.utils.bean.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.ruoyi.bst.task.domain.TaskQuery;
import com.ruoyi.bst.task.domain.enums.TaskStatus;
import com.ruoyi.bst.task.service.TaskService;
import com.ruoyi.common.vo.StringIntegerVO;
import com.ruoyi.dashboard.index.domain.brief.TaskBriefVO;
import com.ruoyi.dashboard.task.domain.brief.TaskBriefKeys;

@Service
public class DashboardTaskService {

    @Autowired
    private TaskService taskService;

    public TaskBriefVO selectTaskBrief(TaskQuery query, String ...keys) {
        TaskBriefVO vo = new TaskBriefVO();
        if (keys != null) {
            List<String> keyList = Arrays.asList(keys);
            if (keyList.contains(TaskBriefKeys.STATUS)) {
                List<StringIntegerVO> statusMap = taskService.selectCountGroupByStatus(query);
                vo.setStatusGroup(statusMap);
            }
            if (keyList.contains(TaskBriefKeys.TYPE)) {
                List<StringIntegerVO> typeMap = taskService.selectCountGroupByType(query);
                vo.setTypeGroup(typeMap);
            }
            if (keyList.contains(TaskBriefKeys.OVERDUE_UNCOMPLETED)) {
                vo.setOverdueUncompleted(this.selectCountOverdueUncompleted(query));
            }
            if (keyList.contains(TaskBriefKeys.OVERDUE_COMPLETED)) {
                vo.setOverdueCompleted(this.selectCountOverdueCompleted(query));
            }
        }

        return vo;
    }

    /**
     * 查询逾期未完成任务数
     * @param taskQuery
     * @return
     */
    private int selectCountOverdueUncompleted(TaskQuery taskQuery) {
        TaskQuery query = new TaskQuery();
        BeanUtils.copyBeanProp(query, taskQuery);
        query.setStatusList(TaskStatus.unComplete());
        query.setOverdue(true);
        return taskService.selectCount(query);
    }

    /**
     * 查询逾期完成任务数
     * @param taskQuery
     * @return
     */
    private int selectCountOverdueCompleted(TaskQuery taskQuery) {
        TaskQuery query = new TaskQuery();
        BeanUtils.copyBeanProp(query, taskQuery);
        query.setStatusList(TaskStatus.complete());
        query.setOverdue(true);
        return taskService.selectCount(query);
    }
}
