package com.ruoyi.web.dashboard;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.ruoyi.bst.customer.domain.CustomerQuery;
import com.ruoyi.bst.project.domain.ProjectQuery;
import com.ruoyi.bst.task.domain.TaskQuery;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.dashboard.customer.service.DashboardCustomerService;
import com.ruoyi.dashboard.index.domain.brief.BriefQuery;
import com.ruoyi.dashboard.index.domain.brief.BriefVO;
import com.ruoyi.dashboard.index.service.DashboardService;
import com.ruoyi.dashboard.project.domain.brief.ProjectBriefKeys;
import com.ruoyi.dashboard.project.service.DashboardProjectService;
import com.ruoyi.dashboard.task.domain.brief.TaskBriefKeys;
import com.ruoyi.dashboard.task.service.DashboardTaskService;

@RestController
@RequestMapping("/dashboard")
public class DashboardController extends BaseController {

    @Autowired
    private DashboardService dashboardService;

    @Autowired
    private DashboardProjectService dashboardProjectService;

    @Autowired
    private DashboardTaskService dashboardTaskService;

    @Autowired
    private DashboardCustomerService dashboardCustomerService;

    // 获取本人的统计数据
    @GetMapping("/mineBrief")
    public AjaxResult mineBrief(BriefQuery query) {
        query.setJoinUserId(getUserId());
        query.setScope(true);

        BriefVO result = new BriefVO();

        // 项目概览
        ProjectQuery projectQuery = query.toProjectQuery();
        result.setProject(dashboardProjectService.selectProjectBrief(projectQuery, ProjectBriefKeys.STATUS));

        // 任务概览
        TaskQuery taskQuery = query.toTaskQuery();
        result.setTask(dashboardTaskService.selectTaskBrief(taskQuery, TaskBriefKeys.STATUS));

        // 客户概览
        CustomerQuery customerQuery = query.toCustomerQuery();
        result.setCustomer(dashboardCustomerService.selectCustomerBrief(customerQuery));

        return AjaxResult.success(result);
    }

    // 获取统计数据
    @GetMapping("/brief")
    public AjaxResult brief(BriefQuery query) {
        BriefVO result = new BriefVO();

        // 项目概览
        ProjectQuery projectQuery = query.toProjectQuery();
        result.setProject(dashboardProjectService.selectProjectBrief(projectQuery,
         ProjectBriefKeys.STATUS, 
         ProjectBriefKeys.DEV_COMPLETED,
         ProjectBriefKeys.OVERDUE_DEV_UNCOMPLETED, 
         ProjectBriefKeys.OVERDUE_DEV_COMPLETED
        ));

        // 任务概览
        TaskQuery taskQuery = query.toTaskQuery();
        result.setTask(dashboardTaskService.selectTaskBrief(taskQuery, 
            TaskBriefKeys.STATUS, 
            TaskBriefKeys.TYPE, 
            TaskBriefKeys.OVERDUE_UNCOMPLETED, 
            TaskBriefKeys.OVERDUE_COMPLETED
        ));

        return AjaxResult.success(result);
    }


}
